cumulusci.tasks.metadata.tests package
======================================

Submodules
----------

cumulusci.tasks.metadata.tests.test\_ee\_src module
---------------------------------------------------

.. automodule:: cumulusci.tasks.metadata.tests.test_ee_src
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.metadata.tests.test\_managed\_src module
--------------------------------------------------------

.. automodule:: cumulusci.tasks.metadata.tests.test_managed_src
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.metadata.tests.test\_modify module
--------------------------------------------------

.. automodule:: cumulusci.tasks.metadata.tests.test_modify
    :members:
    :undoc-members:
    :show-inheritance:

cumulusci.tasks.metadata.tests.test\_package module
---------------------------------------------------

.. automodule:: cumulusci.tasks.metadata.tests.test_package
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.metadata.tests
    :members:
    :undoc-members:
    :show-inheritance:
